@@ -2,15 +2,14 @@
 from emora_stdm import DialogueFlow
 
 
-component = DialogueFlow('_local_start')
+component = DialogueFlow('goal')
+component.add_system_transition('goal', 'start', '#GOAL(component) #GATE()')
 component.add_system_transition('exit', 'SYSTEM:root', '')
 component.knowledge_base().load_json_file('common.json')
 component.knowledge_base().load_json_file('component.json')
-component.add_system_transition('_local_start', 'start', '')
 
 system = {
-    'state': 'start',
-    'enter': '#GATE #GOAL(component)'
+    'state': 'start'
 }
 
 user = {
@@ -20,6 +19,5 @@ user = {
 component.load_transitions(system)
 component.load_global_nlu(user)
 
-
 if __name__ == '__main__':
     component.run(debugging=True)
\ No newline at end of file
