@@ -311,15 +311,15 @@ df.add_system_transition(State.YES_LIKE_READING, State.PICK_GENRE, ack_like_read
 df.update_state_settings(State.PICK_GENRE, system_multi_hop=True)
 
 ### (SYSTEM) TALK ABOUT SCIFI
-share_like_scifi = ['"I really enjoy reading science fiction novels."',
-                    '"One of my favorite things to read is science fiction."',
-                    '"I think that science fiction has become a pretty exciting genre for books."']
+share_like_scifi = ['"I really enjoy science fiction. Like "',
+                    '"One of the most interesting topics I have come across is science fiction. Like"',
+                    '"I think that science fiction has become pretty exciting these days. Like"']
 df.add_system_transition(State.PICK_GENRE, State.SCIFI, share_like_scifi)
 df.update_state_settings(State.SCIFI, system_multi_hop=True)
 
 ### (SYSTEM) TALK ABOUT TELEPORTATION
-share_teleport_fun = ['"It would be so cool for teleportation to be real. It would take a lot less time to travel around."',
-                      '"I am really excited when I read about inventions for teleportation. Never having to wait to get somewhere would be amazing."']
+share_teleport_fun = ['"It would be so cool for teleportation to be real. It would take a lot less time for people to travel around."',
+                      '"I am really excited about the idea of teleportation for people. You would be able to just instantly travel from place to place."']
 df.add_system_transition(State.SCIFI, State.SHARE_TELEPORT_FUN, share_teleport_fun)
 df.update_state_settings(State.SHARE_TELEPORT_FUN, system_multi_hop=True)
 
