@@ -250,11 +250,11 @@ component.add_system_transition('start_error', 'opening_chat_choices', "[!" + st
 # NEW USERS
 ##############
 component.add_system_transition('start_new', 'receive_name',
-                                ["[!" + standard_opening + ' What can I call you"?"]',
-                                 "[!" + standard_opening + ' What name would you like me to call you"?"]',
-                                 "[!" + standard_opening + ' What name would you like me to use for you"?"]',
-                                 "[!" + standard_opening + ' May I have your name"?"]',
-                                 "[!" + standard_opening + ' What should I call you"?"]'
+                                ["[!" + standard_opening + ' I do not think we have met before"." What can I call you"?"]',
+                                 "[!" + standard_opening + ' I do not think we have met before"." What name would you like me to call you"?"]',
+                                 "[!" + standard_opening + ' I do not think we have met before"." What name would you like me to use for you"?"]',
+                                 "[!" + standard_opening + ' I do not think we have met before"." May I have your name"?"]',
+                                 "[!" + standard_opening + ' I do not think we have met before"." What should I call you"?"]'
                                  ]
                                 )
 
