@@ -28,7 +28,10 @@ stop_nlu = [
     "[$off_phrase=[!{alexa,echo,computer}, #ONT(ontturn), {#ONT(ontoffpaired),#ONT(ontoff)}]]",
     "[$off_phrase=[!{alexa,echo,computer}, #ONT(ontturn), to, {#ONT(ontoffpaired),#ONT(ontoff)}]]",
     "[$off_phrase={goodnight, good night,shut up}]",
-    "$off_phrase=[!{alexa,echo,computer}?, {cancel,abandon}]"
+    "$off_phrase=[!{alexa,echo,computer}?, {cancel,abandon}]",
+    "[$off_phrase=[!{done,finished,over} {talking,chatting} {now,with you}]]",
+    "[$off_phrase=[!{wanna,want to} {finish,end,stop} {this conversation}]]",
+    "[$off_phrase=[!{wanna,want to} {be} {done,finished}]]"
 ]
 
 #df.add_user_transition(State.START, State.REC_OFF, stop_nlu)
